@@ -1,5 +1,8 @@
+import os, sys
 import guzzle_sphinx_theme
 
+sys.path.insert(0, os.path.abspath('..'))
+
 project = "requests-http-signature"
 copyright = "Andrey Kislyuk"
 author = "Andrey Kislyuk"
